api.assets.v1.test_helpers.businessprocess package — Argus-Toolbelt 1.0 documentation

# api.assets.v1.test_helpers.businessprocess package

## Submodules

## api.assets.v1.test_helpers.businessprocess.add_business_process module

`api.assets.v1.test_helpers.businessprocess.add_business_process.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess, respond with HTTP 403

`api.assets.v1.test_helpers.businessprocess.add_business_process.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess, respond with HTTP 404

`api.assets.v1.test_helpers.businessprocess.add_business_process.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess, respond with HTTP 200

`api.assets.v1.test_helpers.businessprocess.add_business_process.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess, respond with HTTP 401

## api.assets.v1.test_helpers.businessprocess.attach_services_to_business_process module

`api.assets.v1.test_helpers.businessprocess.attach_services_to_business_process.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+/attachservices, respond with HTTP 403

`api.assets.v1.test_helpers.businessprocess.attach_services_to_business_process.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+/attachservices, respond with HTTP 404

`api.assets.v1.test_helpers.businessprocess.attach_services_to_business_process.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+/attachservices, respond with HTTP 200

`api.assets.v1.test_helpers.businessprocess.attach_services_to_business_process.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+/attachservices, respond with HTTP 401

## api.assets.v1.test_helpers.businessprocess.delete_business_process module

`api.assets.v1.test_helpers.businessprocess.delete_business_process.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+, respond with HTTP 403

`api.assets.v1.test_helpers.businessprocess.delete_business_process.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+, respond with HTTP 404

`api.assets.v1.test_helpers.businessprocess.delete_business_process.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+, respond with HTTP 200

`api.assets.v1.test_helpers.businessprocess.delete_business_process.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+, respond with HTTP 401

## api.assets.v1.test_helpers.businessprocess.detach_services_from_business_process module

`api.assets.v1.test_helpers.businessprocess.detach_services_from_business_process.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+/detachservices, respond with HTTP 403

`api.assets.v1.test_helpers.businessprocess.detach_services_from_business_process.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+/detachservices, respond with HTTP 404

`api.assets.v1.test_helpers.businessprocess.detach_services_from_business_process.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+/detachservices, respond with HTTP 200

`api.assets.v1.test_helpers.businessprocess.detach_services_from_business_process.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+/detachservices, respond with HTTP 401

## api.assets.v1.test_helpers.businessprocess.get_business_process module

`api.assets.v1.test_helpers.businessprocess.get_business_process.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+, respond with HTTP 403

`api.assets.v1.test_helpers.businessprocess.get_business_process.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+, respond with HTTP 404

`api.assets.v1.test_helpers.businessprocess.get_business_process.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+, respond with HTTP 200

`api.assets.v1.test_helpers.businessprocess.get_business_process.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+, respond with HTTP 401

## api.assets.v1.test_helpers.businessprocess.search_business_process_statistics module

`api.assets.v1.test_helpers.businessprocess.search_business_process_statistics.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/statistics, respond with HTTP 403

`api.assets.v1.test_helpers.businessprocess.search_business_process_statistics.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/statistics, respond with HTTP 404

`api.assets.v1.test_helpers.businessprocess.search_business_process_statistics.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/statistics, respond with HTTP 200

`api.assets.v1.test_helpers.businessprocess.search_business_process_statistics.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/statistics, respond with HTTP 401

## api.assets.v1.test_helpers.businessprocess.search_business_processes module

`api.assets.v1.test_helpers.businessprocess.search_business_processes.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/search, respond with HTTP 403

`api.assets.v1.test_helpers.businessprocess.search_business_processes.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/search, respond with HTTP 404

`api.assets.v1.test_helpers.businessprocess.search_business_processes.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/search, respond with HTTP 200

`api.assets.v1.test_helpers.businessprocess.search_business_processes.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/search, respond with HTTP 401

## api.assets.v1.test_helpers.businessprocess.search_business_processes_simplified module

`api.assets.v1.test_helpers.businessprocess.search_business_processes_simplified.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess, respond with HTTP 403

`api.assets.v1.test_helpers.businessprocess.search_business_processes_simplified.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess, respond with HTTP 404

`api.assets.v1.test_helpers.businessprocess.search_business_processes_simplified.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess, respond with HTTP 200

`api.assets.v1.test_helpers.businessprocess.search_business_processes_simplified.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess, respond with HTTP 401

## api.assets.v1.test_helpers.businessprocess.update_business_process module

`api.assets.v1.test_helpers.businessprocess.update_business_process.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+, respond with HTTP 403

`api.assets.v1.test_helpers.businessprocess.update_business_process.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+, respond with HTTP 404

`api.assets.v1.test_helpers.businessprocess.update_business_process.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+, respond with HTTP 200

`api.assets.v1.test_helpers.businessprocess.update_business_process.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/businessprocess/w+, respond with HTTP 401

## Module contents